@@ -1,4 +1,6 @@
-use ergo_lib::ergo_rest::NodeError;
+#[cfg(feature = "rest")]
+use ergo_lib::ergo_rest::{NodeError, PeerDiscoveryError};
+
 use std::error;
 use thiserror::Error;
 
@@ -30,8 +32,16 @@ impl Error {
     }
 }
 
+#[cfg(feature = "rest")]
 impl From<NodeError> for Error {
     fn from(error: NodeError) -> Self {
         Error::Misc(format!("{:?}", error).into())
     }
 }
+
+#[cfg(feature = "rest")]
+impl From<PeerDiscoveryError> for Error {
+    fn from(error: PeerDiscoveryError) -> Self {
+        Error::Misc(format!("{:?}", error).into())
+    }
+}
